@@ -2,14 +2,16 @@
 
 from __future__ import absolute_import
 import abc
-import collections
 import re
 import six
+from collections import OrderedDict
 
 if six.PY2:
     from inspect import getargspec as get_arg_spec
+    import collections
 else:
     from inspect import getfullargspec as get_arg_spec
+    import collections.abc as collections
 
 from . import lang
 from . import mixins
@@ -485,7 +487,7 @@ class _If(_Instruction, collections.Sequence):
         return _IfStepper.recreate_from(saved_state, load_context)
 
     def get_description(self):
-        description = collections.OrderedDict()
+        description = OrderedDict()
 
         description['if({})'.format(self._ifs[0].predicate.__name__)] = self._ifs[0].body.get_description()
         for conditional in self._ifs[1:]:
@@ -657,7 +659,7 @@ Use as::
     return_
   )
 
-or
+or::
 
   if_(cls.conditional)(
     return_(EXIT_CODE)
